-- 导入必要的 Android 包
require "import"
import "android.app.*"
import "android.os.*"
import "android.widget.*"
import "android.view.*"
import "android.content.*"
import "android.provider.*"
import "android.telephony.*"
import "android.net.Uri"
import "java.util.*"
import "android.permission.*"
import "android.text.*"
import "android.view.inputmethod.*"
import "android.Manifest"
import "android.content.pm.PackageManager"
import "android.os.Build"
import "java.text.Normalizer"
import "android.view.KeyEvent"

-- 主布局
activity.setTheme(android.R.style.Theme_Holo_Light)
activity.setContentView(loadlayout({
    LinearLayout,
    orientation = "vertical",
    layout_width = "match_parent",
    layout_height = "match_parent",
    {
        EditText,
        id = "numberInput",
        layout_width = "match_parent",
        layout_height = "wrap_content",
        layout_margin = "10dp",
        hint = "输入号码或联系人",
        textSize = "18sp",
        gravity = "center",
        inputType = "text",
        imeOptions = "actionDone"
    },
    {
        LinearLayout, -- 包装容器
        layout_width = "match_parent",
        layout_height = "0dp",
        layout_weight = 0.5,
        gravity = "center",
        {
            GridLayout,
            id = "dialPad",
            layout_width = "wrap_content",
            layout_height = "wrap_content",
            columnCount = 3,
        }
    },
    {
        ListView,
        id = "contactList",
        layout_width = "match_parent",
        layout_height = "0dp",
        layout_weight = 0.5,
        visibility = "gone"
    },
    { -- 用于放置呼叫和删除按钮的布局
        LinearLayout,
        layout_width = "match_parent",
        layout_height = "wrap_content",
        orientation = "horizontal",
        layout_margin = "10dp",
        {
            Button,
            id = "callBtn",
            layout_width = "0dp",
            layout_weight = 1,
            layout_height = "wrap_content",
            text = "呼叫",
            textSize = "18sp",
            onClick = function()
                local number = numberInput.getText().toString()
                if number and number ~= "" then
                    dialNumber(number)
                else
                    local lastNumber = getLastCallNumber()
                    if lastNumber then
                        dialNumber(lastNumber)
                    else
                        Toast.makeText(activity, "无最近通话记录或权限不足", Toast.LENGTH_SHORT).show()
                    end
                end
            end
        },
        {
            Button,
            id = "deleteBtn",
            layout_width = "0dp",
            layout_weight = 1,
            layout_height = "wrap_content",
            text = "删除",
            textSize = "18sp",
            onClick = function()
                local currentText = numberInput.getText().toString()
                if currentText and #currentText > 0 then
                    local newText = string.sub(currentText, 1, #currentText - 1)
                    numberInput.setText(newText)
                    numberInput.setSelection(#newText) -- 将光标移到末尾
                    if #newText == 0 then
                        contactList.setVisibility(View.GONE)
                    else
                        searchContacts(newText)
                    end
                end
            end
        }
    },
    {
        LinearLayout,
        layout_width = "match_parent",
        layout_height = "wrap_content",
        orientation = "horizontal",
        {
            Button,
            id = "callLogBtn",
            layout_width = "0dp",
            layout_weight = 1,
            text = "通话记录: 0",
            onClick = function() showCallLog() end
        },
        {
            Button,
            id = "contactsBtn",
            layout_width = "0dp",
            layout_weight = 1,
            text = "联系人: 0",
            onClick = function() showContacts() end
        }
    }
}))

-- 拨号盘按钮
local dialButtons = {
    {"1", ""}, {"2", ""}, {"3", ""},
    {"4", ""}, {"5", ""}, {"6", ""},
    {"7", ""}, {"8", ""}, {"9", ""},
    {"*", ""}, {"0", ""}, {"#", ""}
}

-- 创建拨号盘按钮
for i, btn in ipairs(dialButtons) do
    local layout = {
        LinearLayout,
        layout_width = "wrap_content",
        layout_height = "wrap_content",
        orientation = "vertical",
        gravity = "center",
        {
            Button,
            text = btn[1],
            layout_width = "80dp",
            layout_height = "wrap_content",
            textSize = "24sp",
            onClick = function()
                numberInput.append(btn[1])
            end
        },
        {
            TextView,
            text = btn[2],
            layout_width = "wrap_content",
            layout_height = "wrap_content",
            textSize = "12sp"
        }
    }
    dialPad.addView(loadlayout(layout))
end

-- 拨号功能
function dialNumber(number)
    if number and number ~= "" then
        local intent = Intent(Intent.ACTION_CALL)
        intent.setData(Uri.parse("tel:" .. number))
        local ok, err = pcall(function() activity.startActivity(intent) end)
        if not ok then
            Toast.makeText(activity, "拨号失败: " .. tostring(err), Toast.LENGTH_LONG).show()
        end
    else
        Toast.makeText(activity, "号码为空", Toast.LENGTH_SHORT).show()
    end
end

-- 发送短信功能
function sendSMS(number)
    if number and number ~= "" then
        local intent = Intent(Intent.ACTION_SENDTO)
        intent.setData(Uri.parse("smsto:" .. number))
        local ok, err = pcall(function() activity.startActivity(intent) end)
        if not ok then
            Toast.makeText(activity, "打开短信界面失败: " .. tostring(err), Toast.LENGTH_LONG).show()
        end
    else
        Toast.makeText(activity, "号码为空", Toast.LENGTH_SHORT).show()
    end
end

-- 获取最近通话的号码
function getLastCallNumber()
    local lastNumber = nil
    pcall(function()
        if Build.VERSION.SDK_INT >= Build.VERSION_CODES.M then
            local permission = Manifest.permission.READ_CALL_LOG
            if activity.checkSelfPermission(permission) != PackageManager.PERMISSION_GRANTED then
                Toast.makeText(activity, "请授予通话记录权限", Toast.LENGTH_LONG).show()
                return
            end
        end
        local cursor = activity.getContentResolver().query(
            CallLog.Calls.CONTENT_URI,
            {CallLog.Calls.NUMBER, CallLog.Calls.DATE},
            nil,
            nil,
            CallLog.Calls.DATE .. " DESC"
        )
        if cursor and cursor.moveToFirst() then
            lastNumber = cursor.getString(cursor.getColumnIndex(CallLog.Calls.NUMBER))
            if lastNumber == nil or lastNumber == "" then
                lastNumber = nil
            end
            cursor.close()
        else
            Toast.makeText(activity, "通话记录为空或查询失败", Toast.LENGTH_SHORT).show()
        end
    end, function(err)
        Toast.makeText(activity, "获取最近通话失败: " .. tostring(err), Toast.LENGTH_LONG).show()
    end)
    return lastNumber
end

-- 根据号码查询联系人姓名
function getContactNameByNumber(number)
    if not number or number == "" then return nil end
    local contactName = nil
    pcall(function()
        -- 检查 READ_CONTACTS 权限
        if Build.VERSION.SDK_INT >= Build.VERSION_CODES.M then
            local permission = Manifest.permission.READ_CONTACTS
            if activity.checkSelfPermission(permission) != PackageManager.PERMISSION_GRANTED then
                Toast.makeText(activity, "请授予联系人权限", Toast.LENGTH_LONG).show()
                return
            end
        end
        -- 规范化号码：移除非数字字符（如空格、破折号）
        local cleanNumber = number:gsub("[^%d]", "")
        -- 移除可能的 +86 前缀（或其他国家代码）
        if cleanNumber:match("^%+?%d+") then
            cleanNumber = cleanNumber:gsub("^%+?%d%d", "")
        end
        local uri = ContactsContract.CommonDataKinds.Phone.CONTENT_URI
        local projection = { ContactsContract.CommonDataKinds.Phone.DISPLAY_NAME, ContactsContract.CommonDataKinds.Phone.NUMBER }
        local cursor = activity.getContentResolver().query(uri, projection, nil, nil, nil)
        if cursor and cursor.moveToFirst() then
            repeat
                local dbNumber = cursor.getString(cursor.getColumnIndex(ContactsContract.CommonDataKinds.Phone.NUMBER))
                if dbNumber then
                    local cleanDbNumber = dbNumber:gsub("[^%d]", "")
                    if cleanDbNumber:match("^%+?%d+") then
                        cleanDbNumber = cleanDbNumber:gsub("^%+?%d%d", "")
                    end
                    -- 严格匹配：规范化后的号码完全相等
                    if cleanNumber == cleanDbNumber then
                        contactName = cursor.getString(cursor.getColumnIndex(ContactsContract.CommonDataKinds.Phone.DISPLAY_NAME))
                        break
                    end
                    -- 模糊匹配：号码末尾部分匹配（至少8位）
                    if #cleanNumber >= 8 and #cleanDbNumber >= 8 then
                        local minLen = math.min(#cleanNumber, #cleanDbNumber)
                        local suffixNumber = cleanNumber:sub(-minLen)
                        local suffixDbNumber = cleanDbNumber:sub(-minLen)
                        if suffixNumber == suffixDbNumber then
                            contactName = cursor.getString(cursor.getColumnIndex(ContactsContract.CommonDataKinds.Phone.DISPLAY_NAME))
                            break
                        end
                    end
                end
            until not cursor.moveToNext()
            cursor.close()
        end
    end, function(err)
        Toast.makeText(activity, "查询联系人姓名失败: " .. tostring(err), Toast.LENGTH_LONG).show()
    end)
    return contactName
end

-- 获取通话记录数量
function updateCallLogCount()
    local count = 0
    pcall(function()
        local cursor = activity.getContentResolver().query(CallLog.Calls.CONTENT_URI, {CallLog.Calls._ID}, nil, nil, nil)
        if cursor then
            count = cursor.getCount()
            cursor.close()
        end
    end, function(err)
        Toast.makeText(activity, "读取通话记录失败: " .. tostring(err), Toast.LENGTH_LONG).show()
    end)
    callLogBtn.setText("通话记录: " .. count)
end

-- 获取联系人数量
function updateContactsCount()
    local count = 0
    pcall(function()
        local cursor = activity.getContentResolver().query(ContactsContract.Contacts.CONTENT_URI, {ContactsContract.Contacts._ID}, nil, nil, nil)
        if cursor then
            count = cursor.getCount()
            cursor.close()
        end
    end, function(err)
        Toast.makeText(activity, "读取联系人失败: " .. tostring(err), Toast.LENGTH_LONG).show()
    end)
    contactsBtn.setText("联系人: " .. count)
end

-- 显示通话记录
function showCallLog()
    local list = {}
    local displayList = {}
    pcall(function()
        local cursor = activity.getContentResolver().query(CallLog.Calls.CONTENT_URI, nil, nil, nil, CallLog.Calls.DATE .. " DESC")
        if cursor then
            while cursor.moveToNext() do
                local number = cursor.getString(cursor.getColumnIndex(CallLog.Calls.NUMBER)) or "未知号码"
                local date = cursor.getLong(cursor.getColumnIndex(CallLog.Calls.DATE)) or 0
                local type = cursor.getInt(cursor.getColumnIndex(CallLog.Calls.TYPE)) or 0
                local typeStr = (type == CallLog.Calls.INCOMING_TYPE and "来电") or
                                (type == CallLog.Calls.OUTGOING_TYPE and "去电") or
                                (type == CallLog.Calls.MISSED_TYPE and "未接") or "未知"
                local dateStr = os.date("%Y-%m-%d %H:%M:%S", math.floor(date/1000))
                local displayName = number
                if number ~= "未知号码" then
                    local contactName = getContactNameByNumber(number)
                    if contactName then
                        displayName = contactName
                    end
                end
                local displayStr = string.format("%s (%s) - %s", displayName, typeStr, dateStr)
                table.insert(list, { number = number, date = date, type = type, display = displayStr })
                table.insert(displayList, displayStr)
            end
            cursor.close()
        end
    end, function(err)
        Toast.makeText(activity, "加载通话记录失败: " .. tostring(err), Toast.LENGTH_LONG).show()
    end)
    if #displayList == 0 then
        Toast.makeText(activity, "无通话记录", Toast.LENGTH_SHORT).show()
        return
    end
    local adapter = ArrayAdapter(activity, android.R.layout.simple_list_item_1, String(displayList))
    local dialog = AlertDialog.Builder(activity)
        .setTitle("通话记录")
        .setAdapter(adapter, function(dialog, which)
            local item = list[which + 1]
            if item and item.number and item.number ~= "未知号码" then
                local options = {"拨打电话", "发送短信"}
                local optionsAdapter = ArrayAdapter(activity, android.R.layout.simple_list_item_1, String(options))
                AlertDialog.Builder(activity)
                    .setTitle("选择操作 (" .. item.number .. ")")
                    .setAdapter(optionsAdapter, function(d, w)
                        if w == 0 then
                            dialNumber(item.number)
                        elseif w == 1 then
                            sendSMS(item.number)
                        end
                    end)
                    .setNegativeButton("取消", nil)
                    .show()
            else
                Toast.makeText(activity, "无法获取有效号码", Toast.LENGTH_SHORT).show()
            end
        end)
        .setNegativeButton("关闭", nil)
        .create()
    dialog.show()
end

-- 显示联系人
function showContacts()
    local list = {}
    local contactsData = {}
    pcall(function()
        local projection = { ContactsContract.Contacts._ID, ContactsContract.Contacts.DISPLAY_NAME }
        local cursor = activity.getContentResolver().query(ContactsContract.Contacts.CONTENT_URI, projection, nil, nil, ContactsContract.Contacts.SORT_KEY_PRIMARY)
        if cursor then
            local idCol = cursor.getColumnIndex(ContactsContract.Contacts._ID)
            local nameCol = cursor.getColumnIndex(ContactsContract.Contacts.DISPLAY_NAME)
            while cursor.moveToNext() do
                local id = cursor.getString(idCol)
                local name = cursor.getString(nameCol) or "未知联系人"
                local numbers = {}
                local phoneProjection = { ContactsContract.CommonDataKinds.Phone.NUMBER }
                local phoneCursor = activity.getContentResolver().query(
                    ContactsContract.CommonDataKinds.Phone.CONTENT_URI, phoneProjection,
                    ContactsContract.CommonDataKinds.Phone.CONTACT_ID .. " = ?", {id}, ContactsContract.CommonDataKinds.Phone.IS_PRIMARY .. " DESC")
                if phoneCursor then
                    local numberColPhone = phoneCursor.getColumnIndex(ContactsContract.CommonDataKinds.Phone.NUMBER)
                    while phoneCursor.moveToNext() do
                        local number = phoneCursor.getString(numberColPhone) or "无号码"
                        local found = false
                        for _, existingNum in ipairs(numbers) do if existingNum == number then found = true break end end
                        if not found then table.insert(numbers, number) end
                    end
                    phoneCursor.close()
                end
                local displayText = name
                if #numbers > 0 then
                    displayText = displayText .. " (" .. numbers[1]
                    if #numbers > 1 then displayText = displayText .. ", +" .. (#numbers - 1) .. ")" else displayText = displayText .. ")" end
                end
                table.insert(list, displayText)
                table.insert(contactsData, {name = name, numbers = numbers})
            end
            cursor.close()
        end
    end, function(err)
        Toast.makeText(activity, "加载联系人失败: " .. tostring(err), Toast.LENGTH_LONG).show()
    end)
    local adapter = ArrayAdapter(activity, android.R.layout.simple_list_item_1, String(list))
    local dialog = AlertDialog.Builder(activity)
        .setTitle("联系人")
        .setAdapter(adapter, function(dialog, which)
            local contact = contactsData[which + 1]
            if contact then
                if #contact.numbers > 1 then
                    local numberAdapter = ArrayAdapter(activity, android.R.layout.simple_list_item_1, String(contact.numbers))
                    AlertDialog.Builder(activity)
                        .setTitle("选择号码 (" .. contact.name .. ")")
                        .setAdapter(numberAdapter, function(d, w)
                            local selectedNumber = contact.numbers[w + 1]
                            local options = {"拨打电话", "发送短信"}
                            local optionsAdapter = ArrayAdapter(activity, android.R.layout.simple_list_item_1, String(options))
                            AlertDialog.Builder(activity)
                                .setTitle("选择操作 (" .. selectedNumber .. ")")
                                .setAdapter(optionsAdapter, function(d2, w2)
                                    if w2 == 0 then
                                        dialNumber(selectedNumber)
                                    elseif w2 == 1 then
                                        sendSMS(selectedNumber)
                                    end
                                end)
                                .setNegativeButton("取消", nil)
                                .show()
                        end)
                        .setNegativeButton("取消", nil)
                        .show()
                elseif #contact.numbers == 1 then
                    local options = {"拨打电话", "发送短信"}
                    local optionsAdapter = ArrayAdapter(activity, android.R.layout.simple_list_item_1, String(options))
                    AlertDialog.Builder(activity)
                        .setTitle("选择操作 (" .. contact.numbers[1] .. ")")
                        .setAdapter(optionsAdapter, function(d, w)
                            if w == 0 then
                                dialNumber(contact.numbers[1])
                            elseif w == 1 then
                                sendSMS(contact.numbers[1])
                            end
                        end)
                        .setNegativeButton("取消", nil)
                        .show()
                else
                    Toast.makeText(activity, "该联系人无号码", Toast.LENGTH_SHORT).show()
                end
            end
        end)
        .create()
    dialog.show()
end

-- 拼音转化简化函数
function toPinyin(str)
    str = str:lower()
    str = Normalizer.normalize(str, Normalizer.Form.NFD)
    return str:gsub("[%p%c%s]", ""):gsub("[']", "")
end

-- 查找联系人号码（支持多号码）
function findNumber(input)
    local contactsData = {}
    pcall(function()
        local cr = activity.getContentResolver()
        local uri = ContactsContract.CommonDataKinds.Phone.CONTENT_URI
        local projection = {
            ContactsContract.CommonDataKinds.Phone.DISPLAY_NAME,
            ContactsContract.CommonDataKinds.Phone.NUMBER,
            ContactsContract.CommonDataKinds.Phone.CONTACT_ID
        }
        local cursor
        if Build.VERSION.SDK_INT >= 26 then
            local selection = ContactsContract.CommonDataKinds.Phone.DISPLAY_NAME .. " LIKE ?"
            local selectionArgs = {"%" .. input .. "%"}
            cursor = cr.query(uri, projection, selection, selectionArgs, nil)
        else
            cursor = cr.query(uri, projection, nil, nil, nil)
        end
        if cursor and cursor.getCount() > 0 then
            local contactsMap = {}
            while cursor.moveToNext() do
                local name = cursor.getString(0) or "未知联系人"
                local number = cursor.getString(1) or "无号码"
                local contactId = cursor.getString(2)
                local cleanInput = input:gsub("%s+", ""):lower()
                local nameMatch = name:lower():find(cleanInput, 1, true)
                local pinyinMatch = toPinyin(name):find(cleanInput, 1, true)
                local numberMatch = number:find(cleanInput, 1, true)
                if nameMatch or pinyinMatch or numberMatch then
                    if not contactsMap[contactId] then
                        contactsMap[contactId] = {name = name, numbers = {}}
                    end
                    local cleanNumber = number:gsub("[%-%s]", "")
                    local found = false
                    for _, existingNum in ipairs(contactsMap[contactId].numbers) do
                        if existingNum == cleanNumber then found = true break end
                    end
                    if not found then
                        table.insert(contactsMap[contactId].numbers, cleanNumber)
                    end
                end
            end
            cursor.close()
            for _, contact in pairs(contactsMap) do
                if #contact.numbers > 0 then
                    table.insert(contactsData, {name = contact.name, numbers = contact.numbers})
                end
            end
        end
    end, function(err)
        Toast.makeText(activity, "搜索联系人失败: " .. tostring(err), Toast.LENGTH_LONG).show()
    end)
    return contactsData
end

-- 搜索联系人功能
function searchContacts(query)
    if not query or query == "" then
        local adapter = ArrayAdapter(activity, android.R.layout.simple_list_item_1, String({}))
        contactList.setAdapter(adapter)
        contactList.setVisibility(View.GONE)
        return {}
    end
    local list = {}
    local contactsData = findNumber(query)
    for _, contact in ipairs(contactsData) do
        local displayText = contact.name
        if #contact.numbers > 0 then
            displayText = displayText .. " (" .. contact.numbers[1]
            if #contact.numbers > 1 then
                displayText = displayText .. ", +" .. (#contact.numbers - 1) .. ")"
            else
                displayText = displayText .. ")"
            end
        end
        table.insert(list, displayText)
    end
    local adapter = ArrayAdapter(activity, android.R.layout.simple_list_item_1, String(list))
    contactList.setAdapter(adapter)
    contactList.setVisibility(#list > 0 and View.VISIBLE or View.GONE)
    contactList.setOnItemClickListener(AdapterView.OnItemClickListener({
        onItemClick = function(parent, view, position, id)
            local contact = contactsData[position + 1]
            if contact then
                if #contact.numbers > 1 then
                    numberInput.clearFocus()
                    local imm = activity.getSystemService(Context.INPUT_METHOD_SERVICE)
                    imm.hideSoftInputFromWindow(numberInput.getWindowToken(), 0)
                    local numberAdapter = ArrayAdapter(activity, android.R.layout.simple_list_item_1, String(contact.numbers))
                    AlertDialog.Builder(activity)
                        .setTitle("选择号码 (" .. contact.name .. ")")
                        .setAdapter(numberAdapter, function(d, w)
                            local selectedNumber = contact.numbers[w + 1]
                            local options = {"拨打电话", "发送短信"}
                            local optionsAdapter = ArrayAdapter(activity, android.R.layout.simple_list_item_1, String(options))
                            AlertDialog.Builder(activity)
                                .setTitle("选择操作 (" .. selectedNumber .. ")")
                                .setAdapter(optionsAdapter, function(d2, w2)
                                    if w2 == 0 then
                                        dialNumber(selectedNumber)
                                        numberInput.setText("")
                                        local imm = activity.getSystemService(Context.INPUT_METHOD_SERVICE)
                                        imm.hideSoftInputFromWindow(numberInput.getWindowToken(), 0)
                                        contactList.setVisibility(View.GONE)
                                    elseif w2 == 1 then
                                        sendSMS(selectedNumber)
                                        numberInput.setText("")
                                        local imm = activity.getSystemService(Context.INPUT_METHOD_SERVICE)
                                        imm.hideSoftInputFromWindow(numberInput.getWindowToken(), 0)
                                        contactList.setVisibility(View.GONE)
                                    end
                                end)
                                .setNegativeButton("取消", nil)
                                .show()
                        end)
                        .setNegativeButton("取消", nil)
                        .show()
                elseif #contact.numbers == 1 then
                    numberInput.clearFocus()
                    local imm = activity.getSystemService(Context.INPUT_METHOD_SERVICE)
                    imm.hideSoftInputFromWindow(numberInput.getWindowToken(), 0)
                    local options = {"拨打电话", "发送短信"}
                    local optionsAdapter = ArrayAdapter(activity, android.R.layout.simple_list_item_1, String(options))
                    AlertDialog.Builder(activity)
                        .setTitle("选择操作 (" .. contact.numbers[1] .. ")")
                        .setAdapter(optionsAdapter, function(d, w)
                            if w == 0 then
                                dialNumber(contact.numbers[1])
                                numberInput.setText("")
                                local imm = activity.getSystemService(Context.INPUT_METHOD_SERVICE)
                                imm.hideSoftInputFromWindow(numberInput.getWindowToken(), 0)
                                contactList.setVisibility(View.GONE)
                            elseif w == 1 then
                                sendSMS(contact.numbers[1])
                                numberInput.setText("")
                                local imm = activity.getSystemService(Context.INPUT_METHOD_SERVICE)
                                imm.hideSoftInputFromWindow(numberInput.getWindowToken(), 0)
                                contactList.setVisibility(View.GONE)
                            end
                        end)
                        .setNegativeButton("取消", nil)
                        .show()
                else
                    Toast.makeText(activity, "该联系人无号码", Toast.LENGTH_SHORT).show()
                end
            end
        end
    }))
    return contactsData
end

-- 编辑框文本变化监听
numberInput.addTextChangedListener({
    afterTextChanged = function(s)
        local query = s.toString()
        searchContacts(query)
    end
})

-- 辅助函数：清空输入框并收起键盘
function clearInputAndHideKeyboard()
    numberInput.setText("")
    numberInput.clearFocus()
    local imm = activity.getSystemService(Context.INPUT_METHOD_SERVICE)
    imm.hideSoftInputFromWindow(numberInput.getWindowToken(), 0)
    contactList.setVisibility(View.GONE)
end

-- 编辑框回车键拨号
numberInput.setOnEditorActionListener(TextView.OnEditorActionListener({
    onEditorAction = function(v, actionId, event)
        if actionId == EditorInfo.IME_ACTION_DONE or
           (event and event.getKeyCode() == KeyEvent.KEYCODE_ENTER and event.getAction() == KeyEvent.ACTION_DOWN) then
            local input = numberInput.getText().toString():gsub("^%s*(.-)%s*$", "%1")
            if input and #input > 0 then
                local cleanNumber = input:gsub("[^%d+]", "")
                if #cleanNumber >= 3 and cleanNumber:match("^%+?%d+$") then
                    dialNumber(cleanNumber)
                    clearInputAndHideKeyboard()
                    return true
                end
                local contactsData = searchContacts(input)
                if #contactsData == 1 then
                    local contact = contactsData[1]
                    if #contact.numbers == 1 then
                        numberInput.clearFocus()
                        local imm = activity.getSystemService(Context.INPUT_METHOD_SERVICE)
                        imm.hideSoftInputFromWindow(numberInput.getWindowToken(), 0)
                        local options = {"拨打电话", "发送短信"}
                        local optionsAdapter = ArrayAdapter(activity, android.R.layout.simple_list_item_1, String(options))
                        AlertDialog.Builder(activity)
                            .setTitle("选择操作 (" .. contact.numbers[1] .. ")")
                            .setAdapter(optionsAdapter, function(d, w)
                                if w == 0 then
                                    dialNumber(contact.numbers[1])
                                    clearInputAndHideKeyboard()
                                elseif w == 1 then
                                    sendSMS(contact.numbers[1])
                                    clearInputAndHideKeyboard()
                                end
                            end)
                            .setNegativeButton("取消", nil)
                            .show()
                    elseif #contact.numbers > 1 then
                        numberInput.clearFocus()
                        local imm = activity.getSystemService(Context.INPUT_METHOD_SERVICE)
                        imm.hideSoftInputFromWindow(numberInput.getWindowToken(), 0)
                        local numberAdapter = ArrayAdapter(activity, android.R.layout.simple_list_item_1, String(contact.numbers))
                        AlertDialog.Builder(activity)
                            .setTitle("选择号码 (" .. contact.name .. ")")
                            .setAdapter(numberAdapter, function(d, w)
                                local selectedNumber = contact.numbers[w + 1]
                                local options = {"拨打电话", "发送短信"}
                                local optionsAdapter = ArrayAdapter(activity, android.R.layout.simple_list_item_1, String(options))
                                AlertDialog.Builder(activity)
                                    .setTitle("选择操作 (" .. selectedNumber .. ")")
                                    .setAdapter(optionsAdapter, function(d2, w2)
                                        if w2 == 0 then
                                            dialNumber(selectedNumber)
                                            clearInputAndHideKeyboard()
                                        elseif w2 == 1 then
                                            sendSMS(selectedNumber)
                                            clearInputAndHideKeyboard()
                                        end
                                    end)
                                    .setNegativeButton("取消", nil)
                                    .show()
                            end)
                            .setNegativeButton("取消", nil)
                            .show()
                    else
                        Toast.makeText(activity, "该联系人无号码", Toast.LENGTH_SHORT).show()
                        clearInputAndHideKeyboard() -- 添加清空和收起逻辑
                    end
                else
                    Toast.makeText(activity, "联系人不存在", Toast.LENGTH_SHORT).show()
                    clearInputAndHideKeyboard() -- 添加清空和收起逻辑
                end
            else
                Toast.makeText(activity, "请输入", Toast.LENGTH_SHORT).show()
                clearInputAndHideKeyboard() -- 添加清空和收起逻辑
            end
            return true
        end
        return false
    end
}))
-- 初始化更新数据
updateCallLogCount()
updateContactsCount()